rule win_gazer_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gazer."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gazer"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7511 e8???????? 84c0 7508 }
            // n = 5, score = 300
            //   85c0                 | mov                 ebx, dword ptr [ebx + 0x30]
            //   7511                 | dec                 ecx
            //   e8????????           |                     
            //   84c0                 | mov                 ebp, dword ptr [ebx + 0x38]
            //   7508                 | dec                 ecx

        $sequence_1 = { 85c0 7511 e8???????? 84c0 7508 83c8ff e9???????? }
            // n = 7, score = 300
            //   85c0                 | mov                 dword ptr [eax + 0x14], eax
            //   7511                 | dec                 ecx
            //   e8????????           |                     
            //   84c0                 | mov                 dword ptr [ebx + 0x40], ecx
            //   7508                 | dec                 ecx
            //   83c8ff               | cmp                 ecx, dword ptr [ebx + 0x30]
            //   e9????????           |                     

        $sequence_2 = { 85c0 7511 e8???????? 84c0 }
            // n = 4, score = 300
            //   85c0                 | je                  0x15c9
            //   7511                 | mov                 esi, eax
            //   e8????????           |                     
            //   84c0                 | push                dword ptr [edi]

        $sequence_3 = { ff15???????? 85c0 7511 e8???????? 84c0 7508 83c8ff }
            // n = 7, score = 300
            //   ff15????????         |                     
            //   85c0                 | cmp                 ebp, dword ptr [edi + 0xc]
            //   7511                 | jne                 0x626
            //   e8????????           |                     
            //   84c0                 | push                dword ptr [edi + 0x14]
            //   7508                 | add                 esp, 0x14
            //   83c8ff               | add                 edi, 4

        $sequence_4 = { 7511 e8???????? 84c0 7508 83c8ff e9???????? }
            // n = 6, score = 300
            //   7511                 | dec                 eax
            //   e8????????           |                     
            //   84c0                 | mov                 ecx, dword ptr [ebp - 0x28]
            //   7508                 | dec                 eax
            //   83c8ff               | mov                 dword ptr [ebp - 0x20], edi
            //   e9????????           |                     

        $sequence_5 = { ff15???????? 85c0 7511 e8???????? 84c0 7508 }
            // n = 6, score = 300
            //   ff15????????         |                     
            //   85c0                 | mov                 eax, dword ptr [ebp + 0x14]
            //   7511                 | cmp                 dword ptr [ebp + 0xc], 0
            //   e8????????           |                     
            //   84c0                 | push                esi
            //   7508                 | mov                 esi, dword ptr [ebp + 8]

        $sequence_6 = { 7511 e8???????? 84c0 7508 83c8ff }
            // n = 5, score = 300
            //   7511                 | dec                 eax
            //   e8????????           |                     
            //   84c0                 | cwde                
            //   7508                 | inc                 ecx
            //   83c8ff               | mov                 dword ptr [esp + eax*4], edx

        $sequence_7 = { ff15???????? 85c0 7511 e8???????? 84c0 }
            // n = 5, score = 300
            //   ff15????????         |                     
            //   85c0                 | pop                 esi
            //   7511                 | mov                 dword ptr [esi + 0x40], eax
            //   e8????????           |                     
            //   84c0                 | mov                 ebx, dword ptr [esi + 0x3c]

        $sequence_8 = { 85c0 7511 e8???????? 84c0 7508 83c8ff }
            // n = 6, score = 300
            //   85c0                 | cmp                 edi, ebx
            //   7511                 | jne                 0x78b
            //   e8????????           |                     
            //   84c0                 | dec                 eax
            //   7508                 | cmp                 dword ptr [esi + 0x150], ebp
            //   83c8ff               | je                  0x7fa

        $sequence_9 = { 4133c0 23c1 33c2 4103c1 }
            // n = 4, score = 200
            //   4133c0               | inc                 eax
            //   23c1                 | mov                 dword ptr [ebp - 0x20], eax
            //   33c2                 | lea                 eax, [ebp - 0x20]
            //   4103c1               | push                eax

    condition:
        7 of them and filesize < 950272
}